@@ -7,14 +7,16 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::read_network_conn_info;
-use crate::client::{Client, Config};
+use crate::client::{Client, ClientConfig};
 use crate::types::Keypair;
 use eyre::Result;
 use std::{sync::Once, time::Duration};
 use tempfile::tempdir;
 use tracing_core::{Event, Subscriber};
 use tracing_subscriber::fmt::time::{FormatTime, SystemTime};
-use tracing_subscriber::fmt::{fmt, FmtContext, FormatEvent, FormatFields, FormattedFields};
+use tracing_subscriber::fmt::{
+    fmt, format::Writer, FmtContext, FormatEvent, FormatFields, FormattedFields,
+};
 use tracing_subscriber::{registry::LookupSpan, EnvFilter};
 
 static INIT: Once = Once::new();
@@ -30,7 +32,7 @@ where
     fn format_event(
         &self,
         ctx: &FmtContext<'_, S, N>,
-        writer: &mut dyn std::fmt::Write,
+        mut writer: Writer,
         event: &Event<'_>,
     ) -> std::fmt::Result {
         // Write level and target
@@ -40,7 +42,7 @@ where
         let time = SystemTime::default();
         write!(writer, " {} ", level)?;
 
-        time.format_time(writer)?;
+        time.format_time(&mut writer)?;
 
         writeln!(
             writer,
@@ -77,7 +79,7 @@ where
         })?;
 
         // Write fields on the event
-        ctx.field_format().format_fields(writer, event)?;
+        ctx.field_format().format_fields(writer.by_ref(), event)?;
 
         writeln!(writer)
     }
@@ -114,13 +116,21 @@ pub async fn create_test_client_with(
     let timeout = timeout.map(Duration::from_secs);
     let (genesis_key, bootstrap_nodes) = read_network_conn_info()?;
 
-    let config = Config::new(
+    let standard_wait = if read_prefix_map {
+        // there should be No AE needed and commands should work first time
+        Some(Duration::from_secs(0))
+    } else {
+        // AE may be needed, so lets go with defaults
+        None
+    };
+
+    let config = ClientConfig::new(
         Some(root_dir.path()),
         None,
         genesis_key,
         None,
         timeout,
-        Some(Duration::from_secs(0)),
+        standard_wait,
     )
     .await;
     let client = Client::create_with(
