@@ -33,7 +33,7 @@ struct Id(u64);
 impl ToDbKey for Id {}
 impl Key for Id {}
 
-impl Subdir for KvStore<Id, TestData> {
+impl Subdir for KvStore<TestData> {
     fn subdir() -> &'static Path {
         Path::new("test")
     }
@@ -84,7 +84,7 @@ async fn used_space_increases() -> Result<()> {
 
     let root = temp_dir()?;
     let used_space = UsedSpace::new(u64::MAX);
-    let db = KvStore::<Id, TestData>::new(root.path(), used_space)?;
+    let db = KvStore::<TestData>::new(root.path(), used_space)?;
 
     let used_space_before = db.total_used_space().await;
 
@@ -99,13 +99,8 @@ async fn used_space_increases() -> Result<()> {
         assert!(db.has(&the_data.id)?);
     }
 
-    let mut used_space_after = db.total_used_space().await;
-
-    while used_space_before >= used_space_after {
-        tokio::time::sleep(std::time::Duration::from_millis(200)).await;
-        used_space_after = db.total_used_space().await;
-    }
-
+    db.flush().await?;
+    let used_space_after = db.total_used_space().await;
     assert!(used_space_after > used_space_before);
 
     Ok(())
@@ -119,7 +114,7 @@ async fn used_space_decreases() -> Result<()> {
 
     let root = temp_dir()?;
     let used_space = UsedSpace::new(u64::MAX);
-    let db = KvStore::<Id, TestData>::new(root.path(), used_space)?;
+    let db = KvStore::<TestData>::new(root.path(), used_space)?;
 
     for (index, (data, _size)) in chunks.data_and_sizes.iter().enumerate().rev() {
         let the_data = &TestData {
@@ -138,12 +133,9 @@ async fn used_space_decreases() -> Result<()> {
         db.delete(&key)?;
     }
 
-    let mut used_space_after = db.total_used_space().await;
-
-    while used_space_after >= used_space_before {
-        tokio::time::sleep(std::time::Duration::from_millis(200)).await;
-        used_space_after = db.total_used_space().await;
-    }
+    db.flush().await?;
+    let used_space_after = db.total_used_space().await;
+    assert!(used_space_after < used_space_before);
 
     Ok(())
 }
@@ -155,7 +147,7 @@ async fn successful_put() -> Result<()> {
 
     let root = temp_dir()?;
     let used_space = UsedSpace::new(u64::MAX);
-    let db = KvStore::<Id, TestData>::new(root.path(), used_space)?;
+    let db = KvStore::<TestData>::new(root.path(), used_space)?;
 
     for (index, (data, _size)) in chunks.data_and_sizes.iter().enumerate().rev() {
         let the_data = &TestData {
@@ -259,39 +251,40 @@ async fn put_and_get_value_should_be_same() -> Result<()> {
 }
 
 #[tokio::test(flavor = "multi_thread")]
-async fn overwrite_value() -> Result<()> {
+async fn no_overwrite_value() -> Result<()> {
     let mut rng = new_rng();
     let chunks = Chunks::gen(&mut rng)?;
+    let (first_chunk, remaining_chunks) = chunks
+        .data_and_sizes
+        .split_first()
+        .expect("generated empty chunks");
 
     let root = temp_dir()?;
     let used_space = UsedSpace::new(u64::MAX);
     let db = KvStore::new(root.path(), used_space)?;
 
-    let key = &Id(0);
-    let mut total_used_space = db.total_used_space().await;
+    let initial_used_space = db.total_used_space().await;
 
-    for (data, size) in chunks.data_and_sizes {
+    let key = &Id(0);
+    db.store(&TestData {
+        id: *key,
+        value: first_chunk.0.clone(),
+    })
+    .await?;
+    db.flush().await?;
+
+    let total_used_space = db.total_used_space().await;
+    assert!(total_used_space >= initial_used_space + first_chunk.1);
+
+    for (data, _) in remaining_chunks {
         db.store(&TestData {
             id: *key,
             value: data.clone(),
         })
         .await?;
 
-        while !db.has(key)? {
-            tokio::time::sleep(std::time::Duration::from_millis(200)).await;
-        }
-
-        loop {
-            let used_space = db.total_used_space().await;
-            if used_space >= size + total_used_space {
-                total_used_space += size;
-                break;
-            }
-            tokio::time::sleep(std::time::Duration::from_millis(200)).await;
-        }
-
-        let retrieved_data = db.get(key)?;
-        assert_eq!(data, retrieved_data.value);
+        assert_eq!(db.total_used_space().await, total_used_space);
+        assert_eq!(db.get(key)?.value, first_chunk.0);
     }
 
     Ok(())
@@ -301,7 +294,7 @@ async fn overwrite_value() -> Result<()> {
 async fn get_fails_when_key_does_not_exist() -> Result<()> {
     let root = temp_dir()?;
     let used_space = UsedSpace::new(u64::MAX);
-    let db: KvStore<Id, TestData> = KvStore::new(root.path(), used_space)?;
+    let db: KvStore<TestData> = KvStore::new(root.path(), used_space)?;
 
     let id = Id(new_rng().gen());
     match db.get(&id) {
